@@ -53,7 +53,7 @@ MonitorsWidget::MonitorsWidget(QWidget *parent)
 
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
 
-    KConfigGroup config(KSharedConfig::openConfig(), "MonitorsWidget");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("MonitorsWidget"));
 
     mTreeView->header()->restoreState(config.readEntry<QByteArray>("state", QByteArray()));
     mSubscriberView->header()->restoreState(config.readEntry<QByteArray>("subscriberViewState", QByteArray()));
@@ -61,7 +61,7 @@ MonitorsWidget::MonitorsWidget(QWidget *parent)
 
 MonitorsWidget::~MonitorsWidget()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "MonitorsWidget");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("MonitorsWidget"));
     config.writeEntry("state", mTreeView->header()->saveState());
     config.writeEntry("subscriberViewState", mSubscriberView->header()->saveState());
 }
@@ -150,7 +150,7 @@ void MonitorsWidget::onSubscriberSelected(const QModelIndex &index)
     auto ifsItem = new QStandardItem(i18n("Item Fetch Scope"));
     const auto ifs = subscriber.itemFetchScope();
     appendRow(ifsItem, i18n("Payload Parts"), toString(ifs.payloadParts()));
-    appendRow(ifsItem, i18n("Full Paryload"), toString(ifs.fullPayload()));
+    appendRow(ifsItem, i18n("Full Payload"), toString(ifs.fullPayload()));
     appendRow(ifsItem, i18n("Attributes"), toString(ifs.attributes()));
     appendRow(ifsItem, i18n("All Attributes"), toString(ifs.allAttributes()));
     appendRow(ifsItem, i18n("Cache only"), toString(ifs.cacheOnly()));
@@ -173,3 +173,5 @@ void MonitorsWidget::onSubscriberSelected(const QModelIndex &index)
 
     mSubscriberView->expandAll();
 }
+
+#include "moc_monitorswidget.cpp"
